@@ -26,8 +26,13 @@
 #include <QFileInfo>
 
 #undef slots
+#include "utils/boost-warnings.h"
 #include <boost/python.hpp>
 
+#ifdef __clang__
+#pragma clang diagnostic pop
+#endif
+
 namespace bp = boost::python;
 
 namespace CalamaresPython
@@ -52,6 +57,9 @@ variantToPyObject( const QVariant& variant )
     case QVariant::Int:
         return bp::object( variant.toInt() );
 
+    case QVariant::LongLong:
+        return bp::object( variant.toLongLong() );
+
     case QVariant::Double:
         return bp::object( variant.toDouble() );
 
