@@ -6,7 +6,7 @@
 #   Copyright 2014-2015, Philip Müller <philm@manjaro.org>
 #   Copyright 2015-2017, Teo Mrnjavac <teo@kde.org>
 #   Copyright 2017, Alf Gaida <agaida@siduction.org>
-#   Copyright 2017, Adriaan de Groot <groot@kde.org>
+#   Copyright 2017, 2019, Adriaan de Groot <groot@kde.org>
 #   Copyright 2017-2018, Gabriel Craciunescu <crazy@frugalware.org>
 #
 #   Calamares is free software: you can redistribute it and/or modify
@@ -26,6 +26,16 @@ import libcalamares
 import os
 import re
 
+import gettext
+_ = gettext.translation("calamares-python",
+                        localedir=libcalamares.utils.gettext_path(),
+                        languages=libcalamares.utils.gettext_languages(),
+                        fallback=True).gettext
+
+
+def pretty_name():
+    return _("Configure GRUB.")
+
 
 def modify_grub_default(partitions, root_mount_point, distributor):
     """
@@ -35,7 +45,13 @@ def modify_grub_default(partitions, root_mount_point, distributor):
 
     :param partitions:
     :param root_mount_point:
-    :param distributor:
+    :param distributor: name of the distributor to fill in for
+        GRUB_DISTRIBUTOR. Must be a string. If the job setting
+        *keepDistributor* is set, then this is only used if no
+        GRUB_DISTRIBUTOR is found at all (otherwise, when *keepDistributor*
+        is set, the GRUB_DISTRIBUTOR lines are left unchanged).
+        If *keepDistributor* is unset or false, then GRUB_DISTRIBUTOR
+        is always updated to set this value.
     :return:
     """
     default_dir = os.path.join(root_mount_point, "etc/default")
@@ -62,12 +78,6 @@ def modify_grub_default(partitions, root_mount_point, distributor):
 
     cryptdevice_params = []
 
-    # GRUB needs to decrypt the partition that /boot is on, which may be / or /boot
-    boot_mountpoint = "/"
-    for partition in partitions:
-        if partition["mountPoint"] == "/boot":
-            boot_mountpoint = "/boot"
-
     if have_dracut:
         for partition in partitions:
             has_luks = "luksMapperName" in partition
@@ -78,7 +88,7 @@ def modify_grub_default(partitions, root_mount_point, distributor):
                 swap_outer_uuid = partition["luksUuid"]
                 swap_outer_mappername = partition["luksMapperName"]
 
-            if (partition["mountPoint"] == boot_mountpoint and has_luks):
+            if (partition["mountPoint"] == "/" and has_luks):
                 cryptdevice_params = [
                     "rd.luks.uuid={!s}".format(partition["luksUuid"])
                     ]
@@ -88,7 +98,7 @@ def modify_grub_default(partitions, root_mount_point, distributor):
             if partition["fs"] == "linuxswap" and not has_luks:
                 swap_uuid = partition["uuid"]
 
-            if (partition["mountPoint"] == boot_mountpoint and has_luks):
+            if (partition["mountPoint"] == "/" and has_luks):
                 cryptdevice_params = [
                     "cryptdevice=UUID={!s}:{!s}".format(
                         partition["luksUuid"], partition["luksMapperName"]
@@ -168,8 +178,13 @@ def modify_grub_default(partitions, root_mount_point, distributor):
                 have_kernel_cmd = True
             elif (lines[i].startswith("#GRUB_DISTRIBUTOR")
                   or lines[i].startswith("GRUB_DISTRIBUTOR")):
-                lines[i] = distributor_line
-                have_distributor_line = True
+                if libcalamares.job.configuration.get("keepDistributor", False):
+                    lines[i] = distributor_line
+                    have_distributor_line = True
+                else:
+                    # We're not updating because of *keepDistributor*, but if
+                    # this was a comment line, then it's still not been set.
+                    have_distributor_line = have_distributor_line or not lines[i].startswith("#")
     else:
         lines = []
 
